@@ -112,8 +112,7 @@
 #' @author Marcelo Araya-Salas (\email{marcelo.araya@@ucr.ac.cr})
 # last modification on may-9-2018 (MAS)
 
-selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE,
-                            extended = FALSE, mar = 0.1, by.song = NULL, pb = TRUE, parallel = 1, verbose = TRUE, skip.error = FALSE, file.format = "\\.wav$|\\.wac$|\\.mp3$|\\.flac$", files = NULL, ...) {
+selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE, extended = FALSE, mar = 0.1, by.song = NULL, pb = TRUE, parallel = 1, verbose = TRUE, skip.error = FALSE, file.format = "\\.wav$|\\.wac$|\\.mp3$|\\.flac$", files = NULL, ...) {
   
   #### set arguments from options
   # get function arguments
@@ -177,11 +176,10 @@ selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE,
   }
 
   if (pb & verbose) {
-    reset_onexit <- .update_progress(total = if(extended) 2 else 1)
-    on.exit(expr = eval(parse(text = reset_onexit)), add = TRUE)  
+  .update_progress(total = if(extended) 2 else 1)
     }
 
-  check.results <- warbleR::check_sels(X, path = path, wav.size = TRUE, pb = pb, ...)
+  check.results <- check_sels(X, path = path, wav.size = TRUE, pb = pb, verbose = verbose, ...)
 
   if (any(check.results$check.res != "OK")) stop2("Not all selections can be read (use check_sels() to locate problematic selections)")
 
@@ -231,14 +229,6 @@ selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE,
           Y$mar.before <- check.results$mar.before
           Y$mar.after <- check.results$mar.after
         }
-
-        # save wave objects as a list attributes
-        ## update progress message
-        if (pb * verbose) {
-          reset_onexit <- .update_progress("saving wave objects into extended selection table", current = 2, total = 2)
-          
-            on.exit(expr = eval(parse(text = reset_onexit)), add = TRUE)
-        }
  
         ## set clusters for windows OS
         if (Sys.info()[1] == "Windows" & parallel > 1) {
@@ -247,7 +237,7 @@ selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE,
           cl <- parallel
         }
 
-        attributes(X)$wave.objects <- pblapply_wrblr_int(pbar = pb, X = 1:nrow(Y), cl = cl, FUN = function(x) warbleR::read_sound_file(X = Y, index = x, from = Y$start[x] - Y$mar.before[x], to = Y$end[x] + Y$mar.after[x], path = path, channel = if (!is.null(X$channel)) X$channel[x] else 1))
+        attributes(X)$wave.objects <- .pblapply(pbar = pb, X = 1:nrow(Y), cl = cl, FUN = function(x) warbleR::read_sound_file(X = Y, index = x, from = Y$start[x] - Y$mar.before[x], to = Y$end[x] + Y$mar.after[x], path = path, channel = if (!is.null(X$channel)) X$channel[x] else 1), message = if (verbose)  "saving wave objects into extended selection table" else NULL, current = 2, total = 2)
 
         # reset for new dimensions
         check.results$start <- X$start <- check.results$mar.before
